@@ -6,6 +6,97 @@ $(document).ready(function () {
     bar.classList.toggle("change");
   });
   $("select").niceSelect();
+  $("svg").click(function () {
+    // console.log($(this));
+    var info = document.querySelector(".status");
+    info.classList.remove("animate1");
+    info.classList.remove("animate2");
+    var reload = document.querySelector("svg");
+    reload.classList.add("reload");
+    $.get("/refresh/demography", function (data, textStatus, jqXHR) {
+      if (data == "Updated") {
+        $(".status").text("Already Updated");
+        info.classList.add("animate1");
+      } else {
+        $(".status").text("Update Done");
+        info.classList.add("animate2");
+      }
+
+      // $(".status").text(null);
+      reload.classList.remove("reload");
+      // info.classList.remove("animate");
+    });
+  });
+  $(".download").click(function () {
+    var date_data = document.getElementById("my_date_picker").value;
+    var e = document.getElementById("state-name");
+    var state = e.options[e.selectedIndex].text;
+    const a = document.createElement("a");
+    a.style.display = "none";
+    document.body.appendChild(a);
+    if (state != "All") {
+      var p = document.getElementById("district-select");
+      var district = p.options[p.selectedIndex].text;
+      if (date_data == "") {
+        a.href = "/get-csv/" + state + "-" + "All";
+      } else {
+        a.href =
+          "/get-csv/" +
+          state +
+          "-" +
+          "(" +
+          date_data.split("/").join("-") +
+          ")";
+      }
+      if (district != "All") {
+        var q = document.getElementById("city-select");
+        var city = q.options[q.selectedIndex].text;
+        if (date_data == "") {
+          a.href = "/get-csv/" + district + "-" + "All";
+        } else {
+          a.href =
+            "/get-csv/" +
+            district +
+            "-" +
+            "(" +
+            date_data.split("/").join("-") +
+            ")";
+        }
+
+        if (city != "All") {
+          if (date_data == "") {
+            a.href = "/get-csv/" + city + "-" + "All";
+          } else {
+            a.href =
+              "/get-csv/" +
+              city +
+              "-" +
+              "(" +
+              date_data.split("/").join("-") +
+              ")";
+          }
+        }
+      }
+    } else {
+      if (date_data == "") {
+        a.href = "/get-csv/" + state + "-" + "All";
+      } else {
+        a.href =
+          "/get-csv/" +
+          state +
+          "-" +
+          "(" +
+          date_data.split("/").join("-") +
+          ")";
+      }
+    }
+
+    // a.href = "/get-csv/" + result + "-" + daily;
+    // a.setAttribute("download", "Confirmed.csv");
+    a.click();
+    window.URL.revokeObjectURL(a.href);
+    document.body.removeChild(a);
+  });
   GetDemoState();
   $("#state-name").change(function () {
     var el = $(this);
@@ -229,6 +320,9 @@ function GetDemoState() {
         divShowData.innerHTML = "";
         divShowData.appendChild(table);
         divShowData.style.width = "auto";
+        divShowData.style.maxWidth = "80vw";
+        divShowData.style.height = "auto";
+        divShowData.style.maxHeight = "90vh";
         // divShowData.style.background = "grey";
         divShowData.style.overflow = "auto";
         divShowData.style.marginTop = "20px";
